@@ -17,11 +17,11 @@
  
 #include <tdelocale.h>
 
-#include <ntqstring.h>
-#include <ntqlineedit.h>
-#include <ntqradiobutton.h>
-#include <ntqcombobox.h>
-#include <ntqcheckbox.h>
+#include <tqstring.h>
+#include <tqlineedit.h>
+#include <tqradiobutton.h>
+#include <tqcombobox.h>
+#include <tqcheckbox.h>
  
 #include "kbsiteinfo.h"
 #include "customconnectdialog.h"
@@ -33,7 +33,7 @@ CustomConnectDialog::CustomConnectDialog(TQWidget *parent, const char *name ) :
 	mp_dialog = new KasablancaCustomConnectDialog(this);
 	setMainWidget(mp_dialog);
 	
-	connect(mp_dialog->AnonymousCheckBox, SIGNAL(toggled(bool)), SLOT(SLOT_AnonymousToggled(bool)));
+	connect(mp_dialog->AnonymousCheckBox, TQ_SIGNAL(toggled(bool)), TQ_SLOT(SLOT_AnonymousToggled(bool)));
 }
 
 CustomConnectDialog::~CustomConnectDialog()
