@@ -46,7 +46,7 @@ typedef pair<TQString, bool> logentries;
 */
 class FtpSession : public TQObject
 {
-Q_OBJECT
+TQ_OBJECT
 public:
 	enum filecheck
 	{
