@@ -19,7 +19,7 @@
 #define DIRITEM_H
 
 #include "kbitem.h"
-#include <ntqlistview.h>
+#include <tqlistview.h>
 
 /**
   *@author mkulke
