@@ -19,7 +19,7 @@
 */
 class KbTaskView : public TDEListView
 {
-Q_OBJECT
+TQ_OBJECT
 public:
     KbTaskView(TQWidget *parent = 0, const char *name = 0);
     ~KbTaskView();
