@@ -18,11 +18,6 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
   
-// enable > 2gb support (LFS)
-
-#define _LARGEFILE_SOURCE
-#define _LARGEFILE64_SOURCE 
- 
 #include <tqpainter.h>
 #include <tqcolor.h>
   
